==> flt_ali_real_person-0.0.2.tar.gz: ios/Classes/SwiftFltAliRealPersonPlugin.swift <==
import Flutter
import UIKit

public class SwiftFltAliRealPersonPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "flt_ali_real_person", binaryMessenger: registrar.messenger())
    let instance = AliRealPersonPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
    RPSDK.setup()
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    result("startRP " + UIDevice.current.systemVersion)
    if ("startRP" == call.method) {
      let currentController = self.getCurrentViewController() ?? self
      RPSDK.start(withVerifyToken: call.arguments as! String, viewController: currentController as! UIViewController) { result in
        // 建议接入方调用实人认证服务端接口DescribeVerifyResult，
        // 来获取最终的认证状态，并以此为准进行业务上的判断和处理。
        print("实人认证结果：", result);
        switch result.state {
        case .pass:
          // 认证通过。
          break
        case .fail:
          // 认证不通过。
          break
        case .notVerify:
          // 未认证。
          // 通常是用户主动退出或者姓名身份证号实名校验不匹配等原因导致。
          // 具体原因可通过result.errorCode来区分（详见文末错误码说明表格）。
          break
        default:
            break
        }
      }
    }
  }

  public func getCurrentViewController(base: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UIViewController? {
    if let nav = base as? UINavigationController {
      return getCurrentViewController(base: nav.visibleViewController)
    }
    if let tab = base as? UITabBarController {
      return getCurrentViewController(base: tab.selectedViewController)
    }
    if let presented = base?.presentedViewController {
      return getCurrentViewController(base: presented)
    }
    return base
  }
}

==> flt_ali_real_person-0.0.3.tar.gz: ios/Classes/SwiftFltAliRealPersonPlugin.swift <==
import Flutter
import UIKit
import RPSD

public class SwiftFltAliRealPersonPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "flt_ali_real_person", binaryMessenger: registrar.messenger())
    let instance = SwiftFltAliRealPersonPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
    RPSDK.setup()
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    result("startRP " + UIDevice.current.systemVersion)
    if ("startRP" == call.method) {
      let currentController = self.getCurrentViewController() ?? self
      RPSDK.start(withVerifyToken: call.arguments as! String, viewController: currentController as! UIViewController) { result in
        // 建议接入方调用实人认证服务端接口DescribeVerifyResult，
        // 来获取最终的认证状态，并以此为准进行业务上的判断和处理。
        print("实人认证结果：", result);
        switch result.state {
        case .pass:
          // 认证通过。
          break
        case .fail:
          // 认证不通过。
          break
        case .notVerify:
          // 未认证。
          // 通常是用户主动退出或者姓名身份证号实名校验不匹配等原因导致。
          // 具体原因可通过result.errorCode来区分（详见文末错误码说明表格）。
          break
        default:
            break
        }
      }
    }
  }

  public func getCurrentViewController(base: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UIViewController? {
    if let nav = base as? UINavigationController {
      return getCurrentViewController(base: nav.visibleViewController)
    }
    if let tab = base as? UITabBarController {
      return getCurrentViewController(base: tab.selectedViewController)
    }
    if let presented = base?.presentedViewController {
      return getCurrentViewController(base: presented)
    }
    return base
  }
}
